Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(454)

Unified Diff: components/mus/ws/view_tree_host_delegate.h

Issue 1406153004: components/mus/public/interfaces View => Window (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Yet another rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/ws/view_tree_host_connection.cc ('k') | components/mus/ws/view_tree_host_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/ws/view_tree_host_delegate.h
diff --git a/components/mus/ws/view_tree_host_delegate.h b/components/mus/ws/view_tree_host_delegate.h
index 2551b87dbd5d5ea64a43abff663ad6cc8960697f..8c153b640373efec3110de15251d01a3042fa3ad 100644
--- a/components/mus/ws/view_tree_host_delegate.h
+++ b/components/mus/ws/view_tree_host_delegate.h
@@ -10,7 +10,8 @@ namespace mus {
class ViewTreeImpl;
// A ViewTreeHostDelegate interface is implemented by an object that
// has the ViewTreeImpl that is associated with the ViewTreeHostImpl that holds
// a pointer to this object. Typically, a ViewTreeHostDelegate will also manage
// the lifetime of the ViewTreeHostImpl and will delete the object when it gets
// informed of when the Display of the root is closed.
@@ -23,8 +24,8 @@ class ViewTreeHostDelegate {
// Called when the window associated with the root is closed.
virtual void OnDisplayClosed() = 0;
- // Returns the ViewTreeImpl associated with the delegate.
- virtual ViewTreeImpl* GetViewTree() = 0;
+ // Returns the WindowTreeImpl associated with the delegate.
+ virtual ViewTreeImpl* GetWindowTree() = 0;
protected:
virtual ~ViewTreeHostDelegate() {}
« no previous file with comments | « components/mus/ws/view_tree_host_connection.cc ('k') | components/mus/ws/view_tree_host_impl.h » ('j') | no next file with comments »
@@ -10,7 +10,8 @@ namespace mus {
class ViewTreeImpl;
// A ViewTreeHostDelegate interface is implemented by an object that
-// has the ViewTreeImpl that is associated with the ViewTreeHostImpl that holds
+// has the WindowTreeImpl that is associated with the ViewTreeHostImpl that
+// holds
// a pointer to this object. Typically, a ViewTreeHostDelegate will also manage
// the lifetime of the ViewTreeHostImpl and will delete the object when it gets

Powered by Google App Engine
This is Rietveld 408576698